from evoflow.population import genRandIntPopulation
import evoflow.backend as B


def test_randintpop():
    shape = (100, 100, 10)
    pop = genRandIntPopulation(shape, 42, 1)
    assert pop.shape == shape
    assert B.max(pop) == 42
    assert B.min(pop) == 1



# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from termcolor import cprint


def print_debug(component, *msg):
    """Print debug message

    Args:
        component (str): Origin component.
        msg (*str): Debug message. Can be made of multiple chunk like
        a normal print.
    """
    msg = " ".join(str(m) for m in msg)
    cprint('[DEBUG]%s:%s' % (component, msg))



import evoflow.backend as B


def genRandIntPopulation(shape, max_value, min_value=0):
    """Generate a random population of Chromosome made of Integers

    Args:
        (set of ints): shape of the population. Its of the form
        (num_chromosomes, chromosome_dim_1, .... chromesome_dim_n)

        max_value (int): Maximum value taken by a given gene.

        min_value (int, optional): Min value a gene can take. Defaults to 0.

    Returns:
        Tensor: random population.
    """
    high = max_value + 1
    return B.randint(low=min_value, high=high, shape=shape)
